@@ -7,7 +7,7 @@ from rich.style import StyleType
 from .. import events
 from ..layouts.grid import GridLayout
 from ..message import Message
-from ..messages import CursorMoveMessage
+from ..messages import CursorMove
 from ..scrollbar import ScrollTo, ScrollBar
 from ..geometry import clamp
 from ..view import View
@@ -21,6 +21,7 @@ class ScrollView(View):
         self,
         contents: RenderableType | Widget | None = None,
         *,
+        auto_width: bool = False,
         name: str | None = None,
         style: StyleType = "",
         fluid: bool = True,
@@ -30,7 +31,9 @@ class ScrollView(View):
         self.fluid = fluid
         self.vscroll = ScrollBar(vertical=True)
         self.hscroll = ScrollBar(vertical=False)
-        self.window = WindowView("" if contents is None else contents)
+        self.window = WindowView(
+            "" if contents is None else contents, auto_width=auto_width
+        )
         layout = GridLayout()
         layout.add_column("main")
         layout.add_column("vscroll", size=1)
@@ -170,19 +173,19 @@ class ScrollView(View):
         self.animate("x", self.target_x, duration=1, easing="out_cubic")
         self.animate("y", self.target_y, duration=1, easing="out_cubic")
 
-    async def message_scroll_up(self, message: Message) -> None:
+    async def handle_scroll_up(self) -> None:
         self.page_up()
 
-    async def message_scroll_down(self, message: Message) -> None:
+    async def handle_scroll_down(self) -> None:
         self.page_down()
 
-    async def message_scroll_left(self, message: Message) -> None:
+    async def handle_scroll_left(self) -> None:
         self.page_left()
 
-    async def message_scroll_right(self, message: Message) -> None:
+    async def handle_scroll_right(self) -> None:
         self.page_right()
 
-    async def message_scroll_to(self, message: ScrollTo) -> None:
+    async def handle_scroll_to(self, message: ScrollTo) -> None:
         if message.x is not None:
             self.target_x = message.x
         if message.y is not None:
@@ -190,20 +193,25 @@ class ScrollView(View):
         self.animate("x", self.target_x, speed=150, easing="out_cubic")
         self.animate("y", self.target_y, speed=150, easing="out_cubic")
 
-    async def message_window_change(self, message: Message) -> None:
-        virtual_size = self.window.virtual_size
+    def handle_window_change(self, message) -> None:
+        virtual_width, virtual_height = self.window.virtual_size
+        width, height = self.size
+
         self.x = self.validate_x(self.x)
         self.y = self.validate_y(self.y)
-        self.vscroll.virtual_size = virtual_size.height
-        self.vscroll.window_size = self.size.height
+
+        self.hscroll.virtual_size = virtual_width
+        self.hscroll.window_size = width
+        self.vscroll.virtual_size = virtual_height
+        self.vscroll.window_size = height
 
         assert isinstance(self.layout, GridLayout)
 
-        if self.layout.show_column("vscroll", virtual_size.height > self.size.height):
+        if self.layout.show_column("vscroll", virtual_height > height):
             self.refresh()
-        if self.layout.show_row("hscroll", virtual_size.width > self.size.width):
+        if self.layout.show_row("hscroll", virtual_width > width):
             self.refresh()
 
-    def message_cursor_move(self, message: CursorMoveMessage) -> None:
+    def handle_cursor_move(self, message: CursorMove) -> None:
         self.scroll_to_center(message.line)
         message.stop()
